import dataset from "assets/dataset_small.json"
import {
  collection,
  getDocs,
  limit,
  query,
  where,
  type DocumentData,
} from "firebase/firestore/lite"

import type { PlasmoMessaging } from "@plasmohq/messaging"

// import initialized db instance
import { db } from "~background"
import type { data_small } from "~interfaces/data_small"

interface url_data {
  name: string
  url: string
}

const data: data_small[] = dataset

// Querying the urls collection to check if current tab url is valid
async function queryUrls(currentTab: chrome.tabs.Tab) {
  let answer
  const url = currentTab.url.split("/")[2]
  const urlsCollection = query(
    collection(db, "urls"),
    where("url", "==", url),
    limit(1),
  )
  const brandsSnapshot = await getDocs(urlsCollection)
  if (brandsSnapshot.empty) {
    return answer
  } else {
    brandsSnapshot.forEach((doc) => {
      answer = doc.data()
    })
    return answer
  }
}

// Checks if brand exisits in the dataset
function ifExists(tokens: string) {
  const answer = data.find((brand) =>
    tokens.toLowerCase().includes(brand.brand.toLowerCase()),
  )
  return answer
}

function getAnswers(tokens: string, validUrl: DocumentData) {
  let secondAnswer
  // checks if there is a valid brand name in the title of page
  let mainAnswer: data_small = ifExists(tokens)
  // if mainAnswer isnt undefined, check if its the same as the store
  if (
    mainAnswer &&
    validUrl.name.toLowerCase().includes(mainAnswer.brand.toLowerCase())
  ) {
    secondAnswer = mainAnswer
    mainAnswer = ifExists(tokens.replace(secondAnswer.brand, ""))
  } else {
    // checks if the current store name is in the dataset
    secondAnswer = ifExists(validUrl.name)
  }
  return { mainAnswer, secondAnswer }
}

// Background worker handler
// Listens to a message (request) and sends back a response at the end
const handler: PlasmoMessaging.MessageHandler = async (req, res) => {
  let answer
  const queryOptions = { active: true, lastFocusedWindow: true }
  const [tab]: chrome.tabs.Tab[] = await chrome.tabs.query(queryOptions)
  const validUrl = await queryUrls(tab)
  const tokens: string = await tab.title
  if (validUrl) {
    answer = getAnswers(tokens, validUrl)
  }
  if (!answer && !validUrl) {
    res.send(undefined)
  } else {
    res.send({
      answer,
      validUrl,
    })
  }
}

export default handler
