import {
  collection,
  getDocs,
  limit,
  query,
  where,
  type DocumentData,
} from "firebase/firestore/lite"
import type { BrandData } from "interfaces/data_advanced"

import type { PlasmoMessaging } from "@plasmohq/messaging"

import { db } from "~background"

// Querying for advanced data
// Takes one argument -> brandName
async function queryAdvancedData(brandName: string) {
  let brandsData
  const brandsCollection = query(
    collection(db, "companies"),
    where("brand", "==", brandName),
    limit(1),
  )
  const brandsSnapshot = await getDocs(brandsCollection)
  brandsSnapshot.forEach((doc) => {
    brandsData = doc.data()
  })
  return brandsData
}

const handler: PlasmoMessaging.MessageHandler = async (req, res) => {
  try {
    const response = await queryAdvancedData(req.body.name)
    res.send({
      response,
    })
  } catch (e) {
    console.log(e)
  }
}

export default handler
