import path from "path"
import { test as base, chromium, type BrowserContext } from "@playwright/test"

/* 
This file contains the setup for all test cases for the frontend of the app

They are split into 3 sections.
1. Testing UI when a brand is identified (tests.spec.ts)
2. When no brand was identified bu the URL is valid (tests.unknown.spec.ts)
3. URL is not valid (tests.invalid.spec.ts)

Testing helps ensure maintainability and covers functional requirement 11
 */

export const test = base.extend<{
  context: BrowserContext
  extensionId: string
}>({
  context: async ({}, use) => {
    const pathToExtension = path.join(
      "C:/Users/Piotrek/Desktop/leaf/build/",
      "chrome-mv3-prod",
    )
    const context = await chromium.launchPersistentContext("", {
      headless: false,
      args: [
        `--disable-extensions-except=${pathToExtension}`,
        `--load-extension=${pathToExtension}`,
      ],
    })
    await use(context)
    await context.close()
  },
  extensionId: async ({ context }, use) => {
    let [background] = context.serviceWorkers()
    if (!background) background = await context.waitForEvent("serviceworker")

    const extensionId = background.url().split("/")[2]
    await use(extensionId)
  },
})
export const expect = test.expect
